@@ -70,6 +70,7 @@ var annotated_dup =
     [ "pw_impl_module_events", "structpw__impl__module__events.html", "structpw__impl__module__events" ],
     [ "pw_impl_node", "structpw__impl__node.html", null ],
     [ "pw_impl_node_events", "structpw__impl__node__events.html", "structpw__impl__node__events" ],
+    [ "pw_impl_node_rt_events", "structpw__impl__node__rt__events.html", "structpw__impl__node__rt__events" ],
     [ "pw_impl_port", "structpw__impl__port.html", null ],
     [ "pw_impl_port_events", "structpw__impl__port__events.html", "structpw__impl__port__events" ],
     [ "pw_link", "structpw__link.html", null ],
@@ -133,10 +134,6 @@ var annotated_dup =
     [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
     [ "pw_time", "structpw__time.html", "structpw__time" ],
     [ "pw_work_queue", "structpw__work__queue.html", null ],
-    [ "pwtest_context", "structpwtest__context.html", null ],
-    [ "pwtest_spa_plugin", "structpwtest__spa__plugin.html", "structpwtest__spa__plugin" ],
-    [ "pwtest_suite", "structpwtest__suite.html", null ],
-    [ "pwtest_test", "structpwtest__test.html", null ],
     [ "spa_audio_aec", "structspa__audio__aec.html", "structspa__audio__aec" ],
     [ "spa_audio_aec_events", "structspa__audio__aec__events.html", "structspa__audio__aec__events" ],
     [ "spa_audio_aec_info", "structspa__audio__aec__info.html", "structspa__audio__aec__info" ],
@@ -151,6 +148,7 @@ var annotated_dup =
     [ "spa_audio_info_flac", "structspa__audio__info__flac.html", "structspa__audio__info__flac" ],
     [ "spa_audio_info_iec958", "structspa__audio__info__iec958.html", "structspa__audio__info__iec958" ],
     [ "spa_audio_info_mp3", "structspa__audio__info__mp3.html", "structspa__audio__info__mp3" ],
+    [ "spa_audio_info_opus", "structspa__audio__info__opus.html", "structspa__audio__info__opus" ],
     [ "spa_audio_info_ra", "structspa__audio__info__ra.html", "structspa__audio__info__ra" ],
     [ "spa_audio_info_raw", "structspa__audio__info__raw.html", "structspa__audio__info__raw" ],
     [ "spa_audio_info_vorbis", "structspa__audio__info__vorbis.html", "structspa__audio__info__vorbis" ],
@@ -274,6 +272,7 @@ var annotated_dup =
     [ "spa_poll_event", "structspa__poll__event.html", "structspa__poll__event" ],
     [ "spa_port_info", "structspa__port__info.html", "structspa__port__info" ],
     [ "spa_process_latency_info", "structspa__process__latency__info.html", "structspa__process__latency__info" ],
+    [ "spa_ratelimit", "structspa__ratelimit.html", "structspa__ratelimit" ],
     [ "spa_rectangle", "structspa__rectangle.html", "structspa__rectangle" ],
     [ "spa_region", "structspa__region.html", "structspa__region" ],
     [ "spa_result_device_params", "structspa__result__device__params.html", "structspa__result__device__params" ],
@@ -287,6 +286,7 @@ var annotated_dup =
     [ "spa_support", "structspa__support.html", "structspa__support" ],
     [ "spa_system", "structspa__system.html", "structspa__system" ],
     [ "spa_system_methods", "structspa__system__methods.html", "structspa__system__methods" ],
+    [ "spa_tag_info", "structspa__tag__info.html", "structspa__tag__info" ],
     [ "spa_thread", "structspa__thread.html", null ],
     [ "spa_thread_utils", "structspa__thread__utils.html", "structspa__thread__utils" ],
     [ "spa_thread_utils_methods", "structspa__thread__utils__methods.html", "structspa__thread__utils__methods" ],
